@@ -5,25 +5,27 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef MESSAGECOMPOSER_RECIPIENTSPICKER_H
-#define MESSAGECOMPOSER_RECIPIENTSPICKER_H
+#pragma once
 
 #include <MessageComposer/Recipient>
 
-#include <kcontacts/addressee.h>
 #include <QDialog>
+#include <kcontacts/addressee.h>
 
 class QPushButton;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class LdapSearchDialog;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class RecipientsPickerWidget;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class RecipientsPicker : public QDialog
 {
     Q_OBJECT
@@ -70,4 +72,3 @@ private:
 };
 }
 
-#endif
