@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRANTLEEHEADERTESTSTYLE_H
-#define GRANTLEEHEADERTESTSTYLE_H
+#pragma once
 
 #include "headerstyle.h"
 #include "messageviewer_export.h"
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class GrantleeHeaderTestStylePrivate;
 /**
  * @brief The GrantleeHeaderTestStyle class
@@ -19,6 +19,7 @@ class GrantleeHeaderTestStylePrivate;
 class MESSAGEVIEWER_EXPORT GrantleeHeaderTestStyle : public HeaderStyle
 {
     friend class GrantleeHeaderStyle;
+
 public:
     GrantleeHeaderTestStyle();
     ~GrantleeHeaderTestStyle() override;
@@ -37,4 +38,3 @@ private:
 };
 }
 
-#endif // GRANTLEEHEADERTESTSTYLE_H
